AI Search SEO API - LLMrefs API Documentation - LLMrefs
LLMrefs AI SEO API
API documentation reference for the AI SEO Search Analytics platform LLMrefs. By default, all users are limited to 10 requests per minute to authenticated endpoints.
LLMrefs Javascript SDK: https://github.com/LLMrefs/llmrefs-js
Server: https://llmrefs.com/api
Authentication
Selected Auth Type: Authorization
| Bearer Token : Show Password |
Organizations
List organizations
Auth Required
Returns the full set of all LLMrefs organizations you have access to.
Responses
- 200
Type: array object[]
| - id | Type: string | required | | - name | Type: string | required |
Request Example for get/v1/organizations
curl https://llmrefs.com/api/v1/organizations \
--header 'Authorization: Bearer YOUR_SECRET_TOKEN'
Successful response
[
{
"id": "string",
"name": "string"
}
]
Projects
List projects
Auth Required
Returns the full set of all projects this LLMrefs organization has access to.
Query Parameters
- organizationId
Type: string min length: 1 required
Responses
- 200
Type: array object[]
| - domain | Type: string | required | | - id | Type: string | required | | - name | Type: string | required |
Request Example for get/v1/projects
curl 'https://llmrefs.com/api/v1/projects?organizationId=' \
--header 'Authorization: Bearer YOUR_SECRET_TOKEN'
Successful response
[
{
"id": "string",
"name": "string",
"domain": "string"
}
]
Keywords
List keywords
Auth Required
Returns the full set of active keywords this LLMrefs project has access to.
Query Parameters
- organizationId
Type: string min length: 1 required
- projectId
Type: string min length: 1 required
Responses
- 200
Type: array object[]
| - id | Type: string | required | | - location | Type: string | required | | - searchVolume | Type: number nullable | required | | - value | Type: string | required |
Request Example for get/v1/keywords
curl 'https://llmrefs.com/api/v1/keywords?organizationId=&projectId=' \
--header 'Authorization: Bearer YOUR_SECRET_TOKEN'
Successful response
[
{
"id": "string",
"value": "string",
"location": "string",
"searchVolume": 1
}
]
List search engines
Auth Required
Returns the full set of generative AI search engines (LLMs) that are tracked by LLMrefs.
Responses
- 200
Type: array object[]
| - name | Type: string | required | | - value | Type: string | required |
Request Example for get/v1/keywords/search-engines
curl https://llmrefs.com/api/v1/keywords/search-engines \
--header 'Authorization: Bearer YOUR_SECRET_TOKEN'
Successful response
[
{
"value": "string",
"name": "string"
}
]
List locations
Auth Required
Returns the full set of available locations that are tracked by LLMrefs.
Responses
- 200
Type: array object[]
| - name | Type: string | required | | - value | Type: string | required |
Request Example for get/v1/keywords/locations
curl https://llmrefs.com/api/v1/keywords/locations \
--header 'Authorization: Bearer YOUR_SECRET_TOKEN'
Successful response
[
{
"value": "string",
"name": "string"
}
]
Get keyword data
Auth Required
Returns the detailed breakdown of the keyword's AI SEO analytics data for the current period.
Path Parameters
- keywordId
Type: string min length: 1 required
Query Parameters
- organizationId
Type: string min length: 1 required
- projectId
Type: string min length: 1 required
- searchEngines
Type: string
Responses
- 200
Type: object
| - brands | Type: array object[] | required | | - id | Type: string | required | | - location | Type: string | required | | - rankings | Type: array object[] | required | | - responses | Type: array object[] | required | | - searchVolume | Type: number nullable | required | | - sources | Type: array object[] | required | | - value | Type: string | required |
Request Example for get/v1/keywords/{keywordId}
curl 'https://llmrefs.com/api/v1/keywords/{keywordId}?organizationId=&projectId=' \
--header 'Authorization: Bearer YOUR_SECRET_TOKEN'
Successful response
{
"id": "string",
"value": "string",
"location": "string",
"searchVolume": 1,
"rankings": [
{
"rank": 1,
"brandId": "string",
"shareOfVoice": "string",
"averagePosition": "string",
"sources": [
"string"
]
}
],
"sources": [
{
"source": "string",
"mentionRate": "string",
"averagePosition": "string",
"brandIds": [
"string"
]
}
],
"responses": [
{
"prompt": "string",
"searchEngine": "string",
"text": "string",
"brandsIds": [
"string"
],
"sources": [
"string"
]
}
],
"brands": [
{
"id": "string",
"name": "string",
"domain": "string"
}
]
}